@@ -31,7 +31,7 @@ logger = function(msg, ...)
 	cat(sys.time, "-", sprintf(msg, ...))
 }
 
-grad.fwd = function(f, x, h = 1e-5, ...) {
+grad_fwd = function(f, x, h = 1e-5, ...) {
 	k = length(x)
 	eye = diag(1, k)
 	res = numeric(k)
@@ -42,7 +42,7 @@ grad.fwd = function(f, x, h = 1e-5, ...) {
 	return(res)
 }
 
-hess.fwd = function(f, x, h = 1e-5, ...) {
+hess_fwd = function(f, x, h = 1e-5, ...) {
 	k = length(x)
 	eye = diag(1, k)
 	H = matrix(NA, k, k)
