@@ -32,26 +32,22 @@ std::pair<double, unsigned int> truncate(double lambda, double nu, double tol,
 		}
 
 		if (y % 10000 == 0) {
-			R_CheckUserInterrupt();
+			Rcpp::checkUserInterrupt();
 		}
 	}
 
 	if (std::isinf(diff)) {
-		char msg[512];
-		snprintf(msg, 512,
+		Rcpp::warning(
 			"Terms of normalizing constant CMP(%g, %g) could not be bounded by "
 			"a geometric series when y <= %g. Consider adjusting the controls "
 			"ymax, hybrid.tol, and truncate.tol",
 			lambda, nu, ymax);
-		Rf_warning(msg);
 	} else if (diff > log_tol) {
-		char msg[512];
-		snprintf(msg, 512,
+		Rcpp::warning(
 			"Absolute relative error %g was larger than tolerance %g with "
 			"CMP(%g, %g) truncated to %g. Consider adjusting the controls "
 			"ymax, hybrid.tol, and truncate.tol",
 			exp(diff), tol, lambda, nu, ymax);
-		Rf_warning(msg);
 	}
 
 	return std::pair<double, unsigned int>(log_z_trunc, y);
